dependent_bterms: Extension of AsymptoticRing to specify a secondary, dependent (monomially bounded) variable
=============================================================================================================

Description
-----------

Extension to SageMath's module for computations with asymptotic expansions. Provides a special AsymptoticRing that allows to specify a secondary, dependent (monomially bounded) variable

License
-------

GPLv3

Upstream Contact
----------------

https://pypi.org/project/dependent-bterms/
